/*
    Copyright (c) 2012 aizo ag, Zurich, Switzerland

    Author: Christian Hitz <christian.hitz@aizo.com>

    This file is part of dS Assistant.

    dS-Assistant is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    dS-Assistant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with digitalSTROM Server. If not, see <http://www.gnu.org/licenses/>.

    NOTE: all APIs, especially the JSON API, offered by this application
          are subject to change without further notice.
*/

#ifdef HAVE_CONFIG_H
    #include "autoconfig.h"
#endif

#include "ds_util.h"
#include "exceptions.h"
#include "storage.h"
#include "log.h"

namespace dSA
{

bool ds_util::isDSMCompatible(dsid_t dsid)
{
    boost::shared_ptr<dSM> dSM;

    try
    {
        dSM = Storage::getInstance()->getDSM(dsid);
    }
    catch (Exception &ex)
    {
        FILE_LOG(logINFO) << "Could not load dSM " <<
            util::str(dsid) << ": " << ex.getMessage();
        return false;
    }

    return dSM->isAPIVersionCompatible();
}

} // namespace
